/**
 * Author: Andrei Heidelbacher
 * Task: Trick
 * Grader - prepare 0
 */

#include <cstdio>
#include <cstdlib>
#include <cstring>

#include <vector>

using namespace std;

const char IN_FILE[] = "trick.in";
const char OUT_FILE[] = "trick.in.0";
const int R = 1;

char DIGITS[10000][5];
int DIGIT_COUNT[10000];

FILE *in = fopen(IN_FILE, "r");
FILE *out = fopen(OUT_FILE, "w");

inline void require(const bool condition, const char *message) {
  if (!condition) {
    fprintf(stderr, "%s", message);
    fclose(in);
    fclose(out);
    exit(0);
  }
}

inline int countDigits(int value) {
  int count = 1;
  for (;;) {
    if (value < 10)
      return count;
    if (value < 100)
      return count + 1;
    if (value < 1000)
      return count + 2;
    if (value < 10000)
      return count + 3;
    value /= 10000;
    count += 4;
  }
  return count;
}

inline void intToString(int value, char buffer[]) {
  const int count = countDigits(value);
  DIGIT_COUNT[value] = count;
  buffer[count] = '\0';
  int position = count - 1;
  for (; value >= 10; value /= 10)
    buffer[position--] = '0' + value % 10;
  buffer[position] = '0' + value;
}

void preprocess() {
  for (int v = 0; v < 10000; ++v)
    intToString(v, DIGITS[v]);
}

class Reader {
 public:
  Reader(FILE *_stream, const int _size = (1 << 16)):
   size(_size),
   pointer(0),
   buffer(new char[_size]),
   stream(_stream) {
    require(fread(buffer, 1, size, stream) != 0, "Corrupted input file!");
  }

  int nextInt() {
    int value = 0;
    while (current() == ' ' || current() == '\n')
      nextPosition();
    require(current() >= '0' && current() <= '9', "Corrupted input file!");
    while(current() >= '0' && current() <= '9') {
      value = value * 10 + current() - '0';
      nextPosition();
    }
    return value;
  }

  Reader &operator>>(int &value) {
    value = nextInt();
    return *this;
  }

 private:
  int size, pointer;
  char *buffer;
  FILE *stream;

  char current() const {
    return buffer[pointer];
  }

  void nextPosition() {
    if(++pointer == size) {
      require(fread(buffer, 1, size, stream) != 0, "Corrupted input file!");
      pointer = 0;
    }
  }
};

class Writer {
 public:
  Writer(FILE *_stream, const int _size = (1 << 16)):
   size(_size),
   pointer(0),
   buffer(new char[_size]),
   stream(_stream) {}

  void flush() {
    fwrite(buffer, sizeof(char), pointer, stream);
    pointer = 0;
    memset(buffer, 0, sizeof(buffer));
  }

  Writer &operator<<(int value) {
    if (value > 9999) {
      const int v = value / 10000;
      for (int i = 0; DIGITS[v][i] != '\0'; ++i)
        write(DIGITS[v][i]);
      value = value % 10000;
      int zeros = 4 - DIGIT_COUNT[value];
      for (; zeros > 0; --zeros)
        write('0');
    }
    for (int i = 0; DIGITS[value][i] != '\0'; ++i)
      write(DIGITS[value][i]);
    return *this;
  }

  Writer &operator<<(const char c) {
    write(c);
    return *this;
  }

 private:
  int size, pointer;
  char *buffer;
  FILE *stream;

  void write(const char c) {
    buffer[pointer++] = c;
    if (pointer == size) {
      flush();
    }
  }
};

int main() {
  preprocess();
  require(in != NULL, "Missing input file!");
  require(out != NULL, "Missing output file!");
  Reader fin = Reader(in);
  Writer fout = Writer(out);
  int T;
  fin >> T;
  fout << T << '\n' << R << '\n';
  for (; T > 0; --T) {
    int N;
    fin >> N;
    fout << N << '\n';
    for (int i = 0; i < N; ++i) {
      int card;
      fin >> card;
      fout << card;
      if (i + 1 < N)
        fout << ' ';
      else
        fout << '\n';
    }
    for (int i = 0; i < N; ++i) {
      int card;
      fin >> card;
    }
  }
  fout.flush();
  fclose(in);
  fclose(out);
  return 0;
}
