/**
 * Author: Andrei Heidelbacher
 * Task: Trick
 * Grader - verif
 */

#include <cstdio>
#include <cstdlib>

#include <algorithm>
#include <vector>

using namespace std;

const char IN_FILE[] = "trick.in";
const char OK_FILE[] = "trick.ok";
const char OUT_FIRST_FILE[] = "trick.out.0";
const char OUT_SECOND_FILE[] = "trick.out.1";
const char OUT_FILE[] = "trick.out";
const int MAX_T = 1234567;
const int MIN_N = 6;
const int MAX_N = 1234567;

FILE *in = fopen(IN_FILE, "r");
FILE *ok = fopen(OK_FILE, "r");
FILE *outFirst = fopen(OUT_FIRST_FILE, "r");
FILE *outSecond = fopen(OUT_SECOND_FILE, "r");
FILE *out = fopen(OUT_FILE, "r");

inline void result(const int score, const char *message) {
  printf("%d %s", score, message);
  fclose(in);
  fclose(ok);
  fclose(outFirst);
  fclose(outSecond);
  fclose(out);
  exit(0);
}

inline void require(const bool condition, const char *message) {
  if (!condition)
    result(0, message);
}

class Reader {
 public:
  Reader(FILE *_stream, const int _size = (1 << 16)):
   size(_size),
   pointer(0),
   buffer(new char[_size]),
   stream(_stream) {
    require(fread(buffer, 1, size, stream) != 0, "Corrupted input file!");
  }

  int nextInt() {
    int value = 0;
    while (current() == ' ' || current() == '\n')
      nextPosition();
    require(current() >= '0' && current() <= '9', "Corrupted input file!");
    while(current() >= '0' && current() <= '9') {
      value = value * 10 + current() - '0';
      nextPosition();
    }
    return value;
  }

  Reader &operator>>(int &value) {
    value = nextInt();
    return *this;
  }

 private:
  int size, pointer;
  char *buffer;
  FILE *stream;

  char current() const {
    return buffer[pointer];
  }

  void nextPosition() {
    if(++pointer == size) {
      require(fread(buffer, 1, size, stream) != 0, "Corrupted input file!");
      pointer = 0;
    }
  }
};

int main() {
  require(in != NULL, "Missing input file!");
  require(ok != NULL, "Missing ok file!");
  require(outFirst != NULL, "Missing first assistant output file!");
  require(outSecond != NULL, "Missing second assistant output file!");
  require(out != NULL, "Missing magician output file!");
  Reader fin = Reader(in);
  int T;
  fin >> T;
  require(0 < T && T <= MAX_T, "Invalid number of tests in input file!");
  int score;
  require(fscanf(ok, "%d", &score) == 1, "Corrupted ok file!");
  require(0 <= score && score <= 100, "Invalid score in ok file!");
  int sumN = 0;
  for (; T > 0; --T) {
    int N;
    fin >> N;
    require(MIN_N <= N && N <= MAX_N, "Invalid number of cards in input file!");
    sumN += N;
    vector<int> color = vector<int>(2 * N + 1, 0);
    for (int r = 1; r <= 2; ++r) {
      for (int i = 0; i < N; ++i) {
        int card;
        fin >> card;
        require(0 <= card && card <= 2 * N, "Invalid card in input!");
        require(color[card] == 0, "Repeated card in input!");
        color[card] = r;
      }
      int a, b;
      if (r == 1)
        require(fscanf(outFirst, "%d %d", &a, &b) == 2, "Corrupted first assistant output file!");
      else
        require(fscanf(outSecond, "%d %d", &a, &b) == 2, "Corrupted second assistant output file!");
      require(0 <= a && a <= 2 * N && 0 <= b && b <= 2 * N, "Invalid cards from assistant!");
      require(a != b, "Identical cards from assistant!");
      require(color[a] == r && color[b] == r, "Cards from assistant not among received ones!");
    }
    int okMissingCard;
    require(fscanf(ok, "%d", &okMissingCard) == 1, "Corrupted ok file!");
    require(0 <= okMissingCard && okMissingCard <= 2 * N, "Invalid card in ok file!");
    require(color[okMissingCard] == 0, "Missing card in ok file is among cards from input!");
    int outputMissingCard;
    require(fscanf(out, "%d", &outputMissingCard) == 1, "Corrupted magician output file!");
    require(0 <= outputMissingCard && outputMissingCard <= 2 * N, "Invalid missing card in output!");
    require(okMissingCard == outputMissingCard, "Incorrect missing card!");
  }
  require(sumN <= MAX_N, "Invalid sum of number of cards in input file!");
  result(score, "Ok!");
  return 0;
}
